package C::D::F::G;
sub answer { 42 }
1;
